==> webdis-commands-0.0.3.tgz: package/lib/esm/webdis/subscriber.js <==
// https://github.com/nicolasff/webdis#pubsub-with-chunked-transfer-encoding
import { v4 } from "uuid";
// @ts-ignore
import { XMLHttpRequest } from "xmlhttprequest";
import chalk from "chalk";
class Subscriber {
    constructor(url, channel) {
        this.prevResponseLength = 0;
        this.listeners = {};
        this.channel = channel;
        this.url = url;
        this.xhr = new XMLHttpRequest();
        this.xhr.addEventListener("readystatechange", () => this.onReadyStateChange());
        this.xhr.open("GET", `${this.url}/SUBSCRIBE/${this.channel}`);
        this.xhr.send(null);
    }
    onReadyStateChange() {
        var _a, _b;
        if (this.xhr.readyState === 3) {
            const response = this.xhr.responseText;
            const chunk = response.slice(this.prevResponseLength);
            this.prevResponseLength = response.length;
            // Received CHUNK:  {"SUBSCRIBE":["message","test","{\"some_field\": \"some_value\"}"]}
            try {
                const parsedChunk = JSON.parse(chunk);
                const isMessage = ((_a = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _a === void 0 ? void 0 : _a[0]) === "message";
                if (isMessage) {
                    // data will be available in index = 2
                    for (const cb of Object.values(this.listeners)) {
                        /**
                         * callback always gets parsed data.
                         * callback function should always check the type of data it is receiving then do operations on it.
                         */
                        cb((_b = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _b === void 0 ? void 0 : _b[2]);
                    }
                }
            }
            catch (e) {
                console.error(chalk.red(`Unable to process received message`, chunk), chalk.red(e));
            }
        }
    }
    registerCb(cb) {
        const uuid = v4();
        this.listeners[uuid] = cb;
        return uuid;
    }
    unregisterCb(uuid) {
        delete this.listeners[uuid];
    }
    destroy() {
        console.log(chalk.green(`Destroying subscription: `, this.channel));
        // empty the listeners
        this.listeners = {};
        // stop the xhr call
        this.xhr.abort();
    }
}
export default Subscriber;

==> webdis-commands-0.0.7.tgz: package/lib/esm/webdis/subscriber.js <==
// https://github.com/nicolasff/webdis#pubsub-with-chunked-transfer-encoding
import { v4 } from "uuid";
// @ts-ignore
import { XMLHttpRequest } from "xmlhttprequest";
import chalk from "chalk";
// @ts-ignore
import base64 from "base-64";
class Subscriber {
    constructor(url, channel, auth) {
        this.prevResponseLength = 0;
        this.listeners = {};
        this.channel = channel;
        this.url = url;
        this.xhr = new XMLHttpRequest();
        this.xhr.addEventListener("readystatechange", () => this.onReadyStateChange());
        this.xhr.open("GET", `${this.url}/SUBSCRIBE/${this.channel}`);
        if (auth) {
            this.xhr.setRequestHeader("Authorization", "Basic " + base64.encode(auth));
        }
        this.xhr.send(null);
    }
    onReadyStateChange() {
        var _a, _b;
        if (this.xhr.readyState === 3) {
            const response = this.xhr.responseText;
            const chunk = response.slice(this.prevResponseLength);
            this.prevResponseLength = response.length;
            // Received CHUNK:  {"SUBSCRIBE":["message","test","{\"some_field\": \"some_value\"}"]}
            try {
                const parsedChunk = JSON.parse(chunk);
                const isMessage = ((_a = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _a === void 0 ? void 0 : _a[0]) === "message";
                if (isMessage) {
                    // data will be available in index = 2
                    for (const cb of Object.values(this.listeners)) {
                        /**
                         * callback always gets parsed data.
                         * callback function should always check the type of data it is receiving then do operations on it.
                         */
                        cb((_b = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _b === void 0 ? void 0 : _b[2]);
                    }
                }
            }
            catch (e) {
                console.error(chalk.red(`Unable to process received message`, chunk), chalk.red(e));
            }
        }
    }
    registerCb(cb) {
        const uuid = v4();
        this.listeners[uuid] = cb;
        return uuid;
    }
    unregisterCb(uuid) {
        delete this.listeners[uuid];
    }
    destroy() {
        console.log(chalk.green(`Destroying subscription: `, this.channel));
        // empty the listeners
        this.listeners = {};
        // stop the xhr call
        this.xhr.abort();
    }
}
export default Subscriber;
